﻿using Infragistics.Win.AppStyling;
using Infragistics.Win.UltraWinSchedule;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace WS_CustomAppointmentDialog
{
    public partial class CustomAppointmentDialog : Form
    {

        private UltraCalendarInfo ultraCalendarInfo1;
        private DateTime[] dates;
        private string subject;
        private Appointment appointment = null;

        public CustomAppointmentDialog(UltraCalendarInfo ultraCalendarInfo1, DateTime[] dates)
        {
            InitializeComponent();
            this.ultraCalendarInfo1 = ultraCalendarInfo1;
            this.dates = dates;

            ultraDateTimeEditor1.Value = dates[0];
            ultraDateTimeEditor2.Value = dates[1].AddSeconds(1);
            SetControlsStyle(ultraDateTimeEditor1);
        }

        public CustomAppointmentDialog(Appointment appointment)
        {
            InitializeComponent();
            this.ultraCalendarInfo1 = appointment.CalendarInfo;
            this.dates = new DateTime[] { appointment.StartDateTime, appointment.EndDateTime };
            this.subject = appointment.Subject;
            this.appointment = appointment;

            ultraDateTimeEditor1.Value = dates[0];
            ultraDateTimeEditor2.Value = dates[1].AddSeconds(1);
            ultraTextEditor1.Text = subject;
            ultraColorPicker1.Color = appointment.BarColor;

            
        }

        private void SetControlsStyle(ISupportAppStyling control)
        {
            control.ComponentRole.StyleLibraryName = "MyStyle";
        }


        private void ultraButton1_Click(object sender, EventArgs e)
        {
            if (ValidateAppointment())
            {
                if (appointment == null)
                {
                    appointment = new Appointment((DateTime)ultraDateTimeEditor1.Value,
                        (DateTime)ultraDateTimeEditor2.Value);
                    appointment.Subject= ultraTextEditor1.Text ;
                    ultraCalendarInfo1.Appointments.Add(appointment);
                    appointment.BarColor = ultraColorPicker1.Color;
                    appointment.Appearance.BorderAlpha = Infragistics.Win.Alpha.Transparent;

                }
                else
                {
                    appointment.Subject = ultraTextEditor1.Text;
                    appointment.StartDateTime = (DateTime)ultraDateTimeEditor1.Value;
                    appointment.EndDateTime = (DateTime)ultraDateTimeEditor2.Value;
                    appointment.BarColor = ultraColorPicker1.Color;
                }
            }
            else
            {
                return;
            }

            this.Close();
        }

        private bool ValidateAppointment()
        {
            bool hasError = false;
            string errorMessage = "The following errors were found:";

            if (String.IsNullOrEmpty(ultraTextEditor1.Text))
            {
                hasError = true;
                errorMessage += "\nThe subject is empty!";
            }
            if (((DateTime)ultraDateTimeEditor1.Value).CompareTo((DateTime)ultraDateTimeEditor2.Value) > 0)
            {
                hasError = true;
                errorMessage += "\nThe start date is after the end date!";
            }
            if (hasError)
            {
                MessageBox.Show(errorMessage, "Appointment error was found!", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            return !hasError;
        }

        private void ultraButton2_Click(object sender, EventArgs e)
        {
            this.Close();
        }

       
    }
}
